@@ -14,7 +14,7 @@
 
 }
 
-regpred=function(Data, max_lag="auto", alpha=0.05, nsim=1000, flg_print=1, direction="<->", loss_function="MAE"){
+regpred=function(Data, max_lag="auto", alpha=0.05, nsim=1000, flg_print=1, direction="<->", loss_function="MSE"){
 
     if(!("data.frame"%in%class(Data)|"data.table"%in%class(Data))){
      stop("Data must be a data.frame or a data.table")
@@ -63,13 +63,13 @@ regpred=function(Data, max_lag="auto", alpha=0.05, nsim=1000, flg_print=1, direc
     res=.Call("regpred_R", Y , max_lag, alpha, nsim, flg_print, direction, loss_function)
  
     res$final$predictions=as.data.frame(res$final$predictions)
-    colnames(res$final$predictions)=c('real', 'fitted', 'upper_bound','predicted','lower_bound')
-    res$final$predictions=res$final$predictions[,c('real', 'upper_bound','predicted','lower_bound')]
+    colnames(res$final$predictions)=c('real', 'fitted', 'lower_bound','predicted','upper_bound')
+    res$final$predictions=res$final$predictions[,c('real', 'lower_bound','predicted','upper_bound')]
 
 	 res$forward$predictions=as.data.frame(res$forward$predictions)
 	 if(nrow(res$forward$predictions)>0){
-	   colnames(res$forward$predictions)=c('real','fitted', 'upper_bound','predicted','lower_bound')
-      res$forward$predictions=res$forward$predictions[,c('real', 'upper_bound','predicted','lower_bound')]
+	   colnames(res$forward$predictions)=c('real','fitted', 'lower_bound','predicted','upper_bound')
+      res$forward$predictions=res$forward$predictions[,c('real', 'lower_bound','predicted','upper_bound')]
       if(length(res$forward$var_x_names)>0){
         res$forward$var_x_names=cols_Y[res$forward$var_x_names+1]  
       }
@@ -77,8 +77,8 @@ regpred=function(Data, max_lag="auto", alpha=0.05, nsim=1000, flg_print=1, direc
 
     res$backward$predictions=as.data.frame(res$backward$predictions) 
 	 if(nrow(res$backward$predictions)>0){
-	   colnames(res$backward$predictions)=c('real', 'fitted', 'upper_bound','predicted','lower_bound')
-      res$backward$predictions=res$backward$predictions[,c('real', 'upper_bound','predicted','lower_bound')]
+	   colnames(res$backward$predictions)=c('real', 'fitted', 'lower_bound','predicted','upper_bound')
+      res$backward$predictions=res$backward$predictions[,c('real', 'lower_bound','predicted','upper_bound')]
       if(length(res$backward$var_x_names)>0){
        res$backward$var_x_names=cols_Y[res$backward$var_x_names+1]  
       }
